@@ -105,7 +105,7 @@ class BackupGatewayClient(BaseClient):
         ActivationKey: str,
         GatewayDisplayName: str,
         GatewayType: Literal["BACKUP_VM"],
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateGatewayOutputTypeDef:
         """
         Creates a backup gateway.
@@ -161,7 +161,7 @@ class BackupGatewayClient(BaseClient):
         Name: str,
         KmsKeyArn: str = ...,
         Password: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         Username: str = ...
     ) -> ImportHypervisorConfigurationOutputTypeDef:
         """
@@ -228,7 +228,7 @@ class BackupGatewayClient(BaseClient):
         """
 
     def tag_resource(
-        self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]
+        self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]
     ) -> TagResourceOutputTypeDef:
         """
         Tag the resource.
